<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### Table of Contents

-   [CFD][1]
    -   [Parameters][2]
    -   [draw][3]
    -   [prediction][4]
    -   [remove][5]
    -   [image][6]
    -   [imageSource][7]
    -   [svgSource][8]

## CFD

<a href='https://travis-ci.com/ulfschneider/cumulative-flow'><img src='https://travis-ci.com/ulfschneider/cumulative-flow.svg?branch=master'/></a>
<a href='https://coveralls.io/github/ulfschneider/cumulative-flow?branch=master'><img src='https://coveralls.io/repos/github/ulfschneider/cumulative-flow/badge.svg?branch=master' /></a>
<a href='https://badge.fury.io/js/cumulative-flow'><img src='https://badge.fury.io/js/cumulative-flow.svg' /></a>

Draw SVG Cumulative Flow Diagrams and predict the anticipated completion of work.

<img src="https://raw.githubusercontent.com/ulfschneider/cumulative-flow/master/cfd.png"/>

Install in your Node project with 

<pre>
npm i cumulative-flow
</pre>

and use it inside your code via 

<pre>
const cfd = require('cumulative-flow');
</pre>

or, alternatively 

<pre>
import cfd from 'cumulative-flow';
</pre>

Create the new cfd objects via

<pre>
let diagram = cfd(settings);
</pre>

### Parameters

-   `settings` **[Object][9]** The configuration object for the diagram. 
    All data for the diagram is provided with this object. 
    In this configuration object, whenever a date is to be given, 
    it can be an [ISO 8601 String][10]
    or a JavaScript [Date][11] object.
    A [Moment][12] object is also fine.
    -   `settings.title` **[String][13]?** The title for the diagram.
    -   `settings.svg` **[Object][9]** The DOM tree element, wich must be an svg tag.
        The diagram will be attached to this DOM tree element. Example:<pre>settings.svg = document.getElementById('cfdDiagram');</pre><code>'cfdDiagram'</code> is the id of a svg tag.
    -   `settings.width` **[Number][14]?** The width of the diagram in pixels, the margin settings have to be included in that width.
    -   `settings.height` **[Number][14]?** The height of the diagram in pixels, the margin settings have to be included in that height.
    -   `settings.margin` **{top: [Number][14], right: [Number][14], bottom: [Number][14], right: [Number][14]}?** The margin for the diagram.
        Default values are:<pre>settings.margin = {
        top: 75,
        right: 210,
        bottom: 30,
        left: 40 }
        </pre>
    -   `settings.fromDate` **([String][13] \| [Date][15])?** The start date for the diagram. Example:<pre>settings.fromDate = '2018-09-01';</pre>
    -   `settings.toDate` **([String][13] \| [Date][15])?** The end date for the diagram. Example:<pre>settings.toDate = '2018-09-05';</pre>
    -   `settings.predict` **([String][13] \| [Date][15])?** To draw an indication line for the completion of work.
        The predict argument determines at what date to start drawing the line. Example:<pre>settings.predict = '2018-09-01';</pre>If no date is provided but the drawOptions allow to draw a prediction line, an automatic
        start date for that line will be calculated based on the first date something went to done.
    -   `settings.shortTermPredict` **[Number][14]?** Indicate the number of days to go back from current date to 
        determine a short term predict start date. This will be used to draw a second prediction line. If 0, no
        short term prediction line is drawn. Default is 0. Example:<pre>settings.shortTermPredict = 30;</pre>
    -   `settings.markers` **[Array][16]&lt;{date: ([String][13] \| [Date][15]), label: [String][13]}>?** Highlight specific dates 
        inside of the diagram with markers. 
        Each marker is an object with a date for the marker and an optional label. It can as well have an optional color. 
        Example:<pre>settings.markers = [
        { date: '2018-09-03', label: 'M1', color: 'green' },
        { date: '2018-09-10', label: 'M2' }];</pre>
    -   `settings.drawOptions` **[Array][16]&lt;[String][13]>?** An array to determine the parts to be drawn. Possible options:<pre>'title' - draw the title
        'axis' - draw the x and y axis
        'legend' - draw the legend information
        'markers' - draw the markers
        'predict' - draw the predict line
        'focus' - draw detailed data when hovering the diagram
        </pre> By default all of these draw options are on.
    -   `settings.style` **[Object][9]?** Influence the appearance of the diagram with typeface and colors. 
        The defaults are:<pre>settings.style = {
        fontSize: 12,
        fontFamily: 'sans-serif',
        color: '#222',
        backgroundColor: '#fff',
        axis: {color: '#222'},
        toDo: {color: '#ccc', stroke: '#fff'},
        progress: {color: '#888', stroke: '#fff', pattern: false},
        done: {color: '#222', stroke: '#fff'},
        markers: {color: '#222', backgroundColor: '#fff'},
        predict: {color: '#222', backgroundColor: '#fff', goodColor: '#222', troubleColor: '#222'},
        shortTermPredict: {color: '#222', backgroundColor: '#fff', goodColor: '#222', troubleColor: '#222'}
        }</pre> A setting of <code>settings.style.progress.pattern = true</code> will ignore the color setting for 
        progress and instead will create a pattern made of the toDo color and the done color. 
        For the prediction, a <code>goodColor</code> is used whenever the workload can be completed within
        the scheduled amount of time and the <code>troubleColor</code> is used in case there is 
        not sufficient time to complete all work.
    -   `settings.data` **{toDo: [Array][16]&lt;[String][13]>, progress: [Array][16]&lt;[String][13]>, done: [Array][16]&lt;[String][13]>, unit: [String][13], entries: [Array][16]&lt;[Object][9]>}** The data for the diagram. Example:<pre>settings.data = {
        toDo: ['new'],
        progress: ['test', 'dev'],
        done: ['done'],
        unit: 'points',
        entries: [
        { date: '2018-09-03', new: 0, dev: 0, test: 0, done: 0 },
        { date: '2018-09-04', new: 1, dev: 0, test: 0, done: 0 },
        { date: '2018-09-05', new: 1, dev: 1, test: 0, done: 0 },
        { date: '2018-09-06', new: 1, dev: 0, test: 1, done: 1 },
        { date: '2018-09-07', new: 2, dev: 1, test: 0, done: 2 },
        { date: '2018-09-08', new: 1, dev: 1, test: 2, done: 2 },
        { date: '2018-09-09', new: 0, dev: 0, test: 1, done: 5 },
        { date: '2018-09-10', new: 1, dev: 1, test: 0, done: 5 }
        ]}</pre>Each entry object must contain a date and the status counts for the
        <code>toDo</code>, <code>progress</code> and <code>done</code> status categories.
        The unit is the unit of measurement for the status counts.
        A value of <code>'points'</code> indicates story points.
        An omitted unit will lead to interpreting the status counts as item counts.
        The status categories <code>toDo</code>, <code>progress</code> and <code>done</code>
        must contain the status values as strings that belong exactly to those categories.
        The rendering of the layers in the Cumulate Flow Diagram will follow the order
        of the status values provided inside of the status categories. All values of the
        <code>done</code> status category are always rendered at the bottom of the diagram,
        beginning from left to right. Then all <code>progress</code> status values, again left to right.
        Finally all <code>new</code> status values, of course left to right.
        For the above example: The <code>done</code> status layer is at the bottom, followed by
        the <code>test</code> and <code>dev</code> layer
        and finally the <code>new</code> layer is getting rendered.

### draw

Draw the Cumulative Flow Diagram inside of the provided <code>settings.svg</code> DOM tree element.

### prediction

Calculate the predict date and the short term predict date

Returns **[Object][9]** with  <code>predict</code> and <code>shortTermPredict</code> dates as strings

### remove

Clear the diagram from the provided <code>settings.svg</code> DOM tree element

### image

Draw the Cumulative Flow Diagram inside of the provided <code>settings.svg</code> DOM tree element 
and return the result as a string which can be assigned to the SRC attribute of an HTML IMG tag.

Returns **[String][13]** 

**Meta**

-   **deprecated**: use imageSource instead


### imageSource

Draw the Cumulative Flow Diagram inside of the provided <code>settings.svg</code> DOM tree element 
and return the result as a string which can be assigned to the SRC attribute of an HTML IMG tag.

Returns **[String][13]** 

### svgSource

Draw the Cumulative Flow Diagram inside of the provided <code>settings.svg</code> DOM tree element 
and return the result as a SVG tag string.

Returns **[String][13]** 

[1]: #cfd

[2]: #parameters

[3]: #draw

[4]: #prediction

[5]: #remove

[6]: #image

[7]: #imagesource

[8]: #svgsource

[9]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object

[10]: https://en.wikipedia.org/wiki/ISO_8601

[11]: https://developer.mozilla.org/de/docs/Web/JavaScript/Reference/Global_Objects/Date

[12]: https://momentjs.com

[13]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String

[14]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Number

[15]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Date

[16]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array
